require 'fimmed_up/connection'
require 'fimmed_up/parameters'
require 'fimmed_up/helpers'

module FimmedUp
 
  class Client
    include FimmedUp::Connection    
    include FimmedUp::Parameters

    # Define the same set of accessors as the FimmedUp module
    attr_accessor *Configuration::VALID_CONFIG_KEYS    
 
    def initialize(options={})
      # Merge the config values from the module and those passed
      # to the client.
      merged_options = FimmedUp.options.merge(options)      
      # Copy the merged values to this client and ignore those
      # not part of our configuration
      Configuration::VALID_CONFIG_KEYS.each do |key|
        send("#{key}=", merged_options[key])
      end
    end

    def find(id)
      record = self.get("#{resource}/#{id}", {}, {})
      if record != ""
        json(record)[0]
      else
        { "error" => "Not Found" }
      end
    end  

    def update(id, args)
      record = self.patch("#{resource}/#{id}", args, {})   
      if record && record != "" then json(record) else { "error" => "Not Found" } end
    end

    def create(args)
      json(self.post(resource, args, {}))
    end

    def updated_count
      self.get("#{resource}/updatedtoday/count", parameters, {}).to_i
    end

    def count
      self.get("#{resource}/count", parameters, {}).to_i     
    end

    def delete(id, args)
      self.delete("#{resource}/#{id}", args, {})
    end
      
  end # Client
 
end